@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,8 +30,8 @@
 #define VZ_RESOURCE_ERROR		6
 #define VZ_ENVCREATE_ERROR		7
 
-#define VZ_COMMAND_EXECUTION_ERROR 	8
-#define VZ_LOCKED 			9
+#define VZ_COMMAND_EXECUTION_ERROR	8
+#define VZ_LOCKED			9
 /* global config file not found */
 #define VZ_NOCONFIG			10
 #define VZ_NOSCRIPT			11
@@ -53,7 +53,7 @@
 #define VZ_VE_TMPL_NOTSET		24
 #define VZ_NOTENOUGHPARAMS		27
 #define VZ_NOTENOUGHUBCPARAMS		28
-#define VZ_VE_PKGSET_NOTSET		29
+#define VZ_VE_OSTEMPLATE_NOTSET		29
 /*****************************
     CT errors
  *****************************/
@@ -130,7 +130,7 @@
 #define	VZ_IP_NA			89
 
 /* Template Error */
-#define VZ_PKGSET_NOT_FOUND		91
+#define VZ_OSTEMPLATE_NOT_FOUND		91
 
 #define VZ_GET_IP_ERROR			100
 #define VZ_NETDEV_ERROR			104
@@ -144,5 +144,8 @@
 #define VZ_VETH_ERROR			130
 #define VZ_SET_NAME_ERROR		131
 #define VZ_WAIT_FAILED			133
-#endif /* _VZ_ERROR_H_ */
 
+#define VZ_CONFIG_SAVE_ERROR		139
+
+#define VZ_SET_OSRELEASE		144
+#endif /* _VZ_ERROR_H_ */
