@@ -470,8 +470,8 @@ int vps_run_script(vps_handler *h, envid_t veid, char *script, vps_param *vps_p)
 				return ret;
 			}
 		}
-		if ((ret = vz_env_create(h, veid, &vps_p->res, rd_p, wr_p,
-					NULL, NULL, NULL)))
+		if ((ret = vz_env_create(h, veid, &vps_p->res, rd_p, NULL,
+					wr_p, NULL, NULL)))
 		{
 			return ret;
 		}
@@ -481,12 +481,17 @@ int vps_run_script(vps_handler *h, envid_t veid, char *script, vps_param *vps_p)
 	ret = vps_exec_script(h, veid, root, argv, NULL, script,
 		NULL, 0);
 	if (!is_run) {
-		write(rd_p[1], &ret, sizeof(ret));
+		/* Close w/o writing to signal we don't want to start init */
+		close(rd_p[1]);
 		retry = 0;
 		while (retry++ < 10 && vps_is_run(h, veid))
 			usleep(500000);
 		if (!is_mounted)
 			fsumount(veid, root);
 	}
+	close(rd_p[0]);
+	close(rd_p[1]);
+	close(wr_p[0]);
+	close(wr_p[1]);
 	return ret;
 }
